==> openshift-model-operatorhub-5.3.0-sources.jar: annotations/io/fabric8/openshift/api/model/operatorhub/v1alpha1/StrategyDeploymentSpecFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.model.apps.DeploymentSpec;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

public interface StrategyDeploymentSpecFluent<A extends StrategyDeploymentSpecFluent<A>> extends Fluent<A> {


    public A addToLabel(String key,String value);
    public A addToLabel(Map<String,String> map);
    public A removeFromLabel(String key);
    public A removeFromLabel(Map<String,String> map);
    public Map<String,String> getLabel();
    public <K extends Object,V extends Object>A withLabel(Map<String,String> label);
    public Boolean hasLabel();
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(StringBuilder arg1);
    public A withNewName(int[] arg1,int arg2,int arg3);
    public A withNewName(char[] arg1);
    public A withNewName(StringBuffer arg1);
    public A withNewName(byte[] arg1,int arg2);
    public A withNewName(byte[] arg1);
    public A withNewName(char[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewName(String arg1);
    public DeploymentSpec getSpec();
    public A withSpec(DeploymentSpec spec);
    public Boolean hasSpec();
}

==> openshift-model-operatorhub-5.3.1-sources.jar: annotations/io/fabric8/openshift/api/model/operatorhub/v1alpha1/StrategyDeploymentSpecFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.model.apps.DeploymentSpec;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

public interface StrategyDeploymentSpecFluent<A extends StrategyDeploymentSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public A addToLabel(String key,String value);
    public A addToLabel(java.util.Map<String,String> map);
    public A removeFromLabel(String key);
    public A removeFromLabel(java.util.Map<String,String> map);
    public java.util.Map<String,String> getLabel();
    public <K extends Object,V extends Object>A withLabel(java.util.Map<String,String> label);
    public Boolean hasLabel();
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(StringBuilder arg1);
    public A withNewName(int[] arg1,int arg2,int arg3);
    public A withNewName(char[] arg1);
    public A withNewName(StringBuffer arg1);
    public A withNewName(byte[] arg1,int arg2);
    public A withNewName(byte[] arg1);
    public A withNewName(char[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewName(String arg1);
    public DeploymentSpec getSpec();
    public A withSpec(DeploymentSpec spec);
    public Boolean hasSpec();
}
